@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0308';
+our $VERSION = '0.0309';
 
 use Moo;
 use strictures 2;
@@ -14,7 +14,7 @@ use List::Util qw/ min /;
 use namespace::clean;
 
 
-has names => (
+has durations => (
     is      => 'ro',
     default => sub { return \%MIDI::Simple::Length },
 );
@@ -28,7 +28,7 @@ has size => (
 
 has pool => (
     is      => 'ro',
-    isa     => sub { die 'Not a non-empty ArrayRef' unless ref( $_[0] ) eq 'ARRAY' && @{ $_[0] } > 0 },
+    isa     => sub { die 'Empty pool not allowed' unless ref( $_[0] ) eq 'ARRAY' && @{ $_[0] } > 0 },
     default => sub { return [ keys %MIDI::Simple::Length ] },
 );
 
@@ -101,7 +101,7 @@ sub motif {
 
 sub _duration {
     my ( $self, $name ) = @_;
-    return $self->names->{$name};
+    return $self->durations->{$name};
 }
 
 1;
@@ -118,7 +118,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0308
+version 0.0309
 
 =head1 SYNOPSIS
 
@@ -135,9 +135,9 @@ version 0.0308
 
   my $motif = $mdp->motif;
 
-  my @scale = get_scale_MIDI('C', 4, 'major');
+  my @scale = get_scale_MIDI( 'C', 4, 'major' );
 
-  my $score = MIDI::Simple->new_score();
+  my $score = MIDI::Simple->new_score;
 
   for my $n ( 0 .. 31 ) { # 4 loops over the motif
     $score->n( $motif->[$n % @$motif], $scale[int rand @scale] );
@@ -153,9 +153,9 @@ durations.
 
 =head1 ATTRIBUTES
 
-=head2 names
+=head2 durations
 
-  $names = $mdp->names;
+  $durations = $mdp->durations;
 
 A hash reference of C<%MIDI::Simple::Length> (keyed by duration name).
 
